slepc-3.18.0 2022-10-01
Report Typos and Errors

# STMatGetSize

Returns the number of rows and columns of the ST matrices.

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STMatGetSize(ST st,PetscInt *m,PetscInt *n)

Not Collective

### Input Parameter

| st | - the spectral transformation context

### Output Parameters

| m | - the number of global rows
| n | - the number of global columns

### See Also

STMatGetLocalSize()

### Level

developer

### Location

src/sys/classes/st/interface/stfunc.c
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages